#
# IRevisionController
#
# Interface for revision controllers like CVS
#
# Copyright (c) 2001-2003 by Philipp "philiKON" von Weitershausen
#
# This software is distributed under the terms of the Mozilla Public License
# (MPL)
#

"""
$Id: IRevisionController.py,v 1.3 2003/01/28 22:22:28 philipp Exp $
"""

from Interface import Interface

class IRevisionController(Interface):
    """
    This interfaces specifies methods that a revision controller such as a
    wrapper class to the cvs command should implement
    """

    def init_repository():
        """
        Initialize a repository
        """

    def status(filename):
        """
        Return status of all objects/files specified in 'filename'. Information
        is return as a sequence of dictionaries.
	
        The parameter 'filename' is a string containing one or more filenames
        separated by white spaces. If filename is an empty string, all files
        in the module directory and all files in all sub-directories are taken
        into account.
        """

    def checkout(filename):
        """
        Checkout file(s) specified by 'filename'. The parsed output is returned
        as a sequence of dictionaries.
        """

    def commit(filename, log_message, opt_param):
        """
        Commit file(s) specified in 'filename'.
        """

    checkin = commit

    def add(filename, binary=0):
        """
        Add file(s) specified in 'filename' to the repository.
        """

    def remove(filename):
        """
        Remove file(s) specified in 'filename' from the repository
        """

    def update(filename, opt_param, opt_tail):
        """
        Update file
        """

    def import_module(import_dir, vendor_tag, release_tag, log_message, ignore_files):
        """
        Import all files in 'import_dir', tag them with 'vendor_tag' and 'release_tag'.
        
        'log_message' is used for the CVS log message.
        'ignore_files' can be an ignore pattern that is passed to CVS.
        """

    def tag(tag, filename):
        """
        Tag file(s) specified in 'filename' with tag.
        """

    def log(filename):
        """
        Return log for file(s) specified in 'filename'.
        """

    def diff(filename, rev1, rev2):
        """
        Return the difference between two revisions, 'rev1' and 'rev2', of all files
        specified in 'filename' as a unix diff.
        """
