#
# IRevisionManager
#
# Copyright (c) 2001-2003 by Philipp "philiKON" von Weitershausen
#
# This software is distributed under the terms of the Mozilla Public License
# (MPL)
#

"""
$Id: IRevisionManager.py,v 1.9 2003/01/25 18:35:34 philipp Exp $
"""

from Interface import Interface

class IRevisionManager(Interface):
    """
    Pure python interface for RevisionManager
    """

    def getSettings():
        """
        Return dictionary containing settings.
        """

    def setSettings(settings):
        """
        Set settings according to the mapping object parameter 'settings'.
        """

    def saveSettings(mapping):
        """
        Save the settings described in the mapping object parameter 'mapping'. Optionally:
        - Clean up things that result from changing the settings.
        - Pass the information to delegated class(es).
        - Prepare further things that result from changing the settings.
        """

    def getFilePaths():
        """
        Return all items' paths managed by this RevisionManager.
        """

    def getFSFilePaths(path=""):
        """
        Return a list of file paths on the file system.

        The parameter 'path' is for recursive calling.
        """

    def getFileInfo(paths=[]):
        """
        List detailled information about internal items.
        """

    def getFSFileInfo():
        """
        Return a sequence of dictionaries containing information about file system
        files and their correspondence in this RevisionManager instance.
        """

    def getSupportedObjectsInfo():
        """
        Return a sequence of dictionaries containing information about objects
        that support to be revision managed and their status in this RevisionManager
        instance.
        """

    def getSupportedFactoryMetaTypes():
        """
        Return a sequence with all meta types supported by the factory
        """

    def getFileStatus(paths=[]):
        """
        List items and check their status in the repository
        """

    def getFileLog(paths=[]):
        """
        List items and their information in the cvs log
        """

    def getModifiedFiles(paths=[]):
        """
        Return a list of modified files identified by their path
        """

    def update(paths=[]):
        """
        Update objects from repository
        """

    def getDiff(path, rev1="", rev2=""):
        """
        Compare two revisions of an object identified by 'path' and return the diff
        as string.
        """

    def addFSFileObject(path, meta_type):
        """
        Add file system file identified by 'path' as an object of type 'meta_type'
        """

    def writeToFS(paths, module_path=None):
        """
        Write objects identified by 'paths' to the filesystem
        """

    def readFromFS(paths):
        """
        Read data for those objects identified by 'paths' from the filesystem
        and upload them into the objects.
        """
